@@ -10,6 +10,14 @@ class TokenExpiredException(Exception):
     pass
 
 
+class ThrottleException(Exception):
+    pass
+
+
+class IOTimeoutException(Exception):
+    pass
+
+
 TIMEOUT = float(os.getenv("GQL_CLIENT_TIMEOUT", "25"))
 print(f"{TIMEOUT=}")
 
@@ -19,8 +27,13 @@ client = httpx.AsyncClient(timeout=TIMEOUT)
 
 def check_for_errors(j: dict) -> None:
     if errors := j.get("errors"):
+        print(f"{errors=}")
         if "Token is expired" in str(errors):
             raise TokenExpiredException(errors)
+        if "Too Many Requests" in str(errors):
+            raise ThrottleException(errors)
+        if "i/o timeout" in str(errors):
+            raise IOTimeoutException(errors)
         raise GQLException(errors)
 
 
