@@ -172,6 +172,10 @@ class Node(BaseModel):
     def _uid_field_name(self) -> str:
         return self.GQL.uid_field_name
 
+    @property
+    def used_resolver(self) -> ResolverType:
+        return self._used_resolver
+
     def __eq__(self, other: Node) -> bool:
         if not isinstance(other, Node):
             return False
@@ -416,8 +420,8 @@ class Node(BaseModel):
         for key, val in obj_d.items():
             if isinstance(val, BaseModel):
                 val = val.json()
-            if isinstance(val, dict):
-                val = json.dumps(jsonable_encoder(val))
+            if type(val) is dict:
+                val = json.dumps(val)
             cleaned_set_d[key] = val
         return cleaned_set_d
 
@@ -431,8 +435,9 @@ class Node(BaseModel):
     ) -> bool:
         set_d, remove_d = self.base_set_remove_d(to_set=to_set, to_remove=to_remove)
         # turn base models or dicts into strs
-        set_d = self.objs_to_str(set_d)
-        remove_d = self.objs_to_str(remove_d)
+        # idk why i have this below??? works when commented out
+        # set_d = self.objs_to_str(set_d)
+        # remove_d = self.objs_to_str(remove_d)
         return await self.update_from_set_remove_ds(
             set_d=set_d,
             remove_d=remove_d,
