@@ -33,9 +33,11 @@ def nested_field_from_selected_field(
             children[camel_to_snake(child.name)] = nested_field_from_selected_field(
                 selected_field=child
             )
-    snake_arguments = {
-        camel_to_snake(key): val for key, val in selected_field.arguments.items()
-    }
+    snake_arguments = {}
+    if getattr(selected_field, "arguments", None):
+        snake_arguments = {
+            camel_to_snake(key): val for key, val in selected_field.arguments.items()
+        }
     return NestedField(args=snake_arguments, children=children)
 
 
